@@ -86,12 +86,15 @@ Store:
 
     get()                      - gets a substore class object for provided substore id
 
+    seal_deduplication_database() - Seals the deduplication database
+
     recover_deduplication_database()    - starts DDB Reconstruction job for store
 
     run_space_reclaimation()    - starts DDB space reclaimation job for store
 
     run_ddb_verification()      - starts DDB verification job for store
 
+    enable_store_pruning        -  Property to get the current state of store pruning or enable/disable store pruning
 
 Substore:
     __init__(commcell_object, storage_policy_name, copy_name,
@@ -107,12 +110,12 @@ Substore:
 
     mark_for_recovery()         - marks a substore for recovery
 """
-
 from __future__ import absolute_import
 from __future__ import unicode_literals
 
 from past.builtins import basestring
 from future.standard_library import install_aliases
+from enum import Enum
 
 from .exception import SDKException
 from .job import Job
@@ -120,6 +123,10 @@ from .job import Job
 install_aliases()
 
 
+class StoreFlags(Enum):
+    IDX_SIDBSTORE_FLAGS_PRUNING_ENABLED = 536870912
+
+
 class DeduplicationEngines(object):
     """Class for getting all the deduplication engines associated with the commcell."""
 
@@ -590,6 +597,12 @@ class Store(object):
             'Storage', '102', f'No substore exists with id: {substore_id}'
         )
 
+    @property
+    def store_flags(self):
+        """returns the deduplication flags on store"""
+        self.refresh()
+        return self._store_flags
+
     @property
     def store_name(self):
         """returns the store display name"""
@@ -632,6 +645,45 @@ class Store(object):
             return False
         return True
 
+    @property
+    def enable_store_pruning(self):
+        """returns if purning is enabled or disabled on store"""
+        return self._store_flags & StoreFlags.IDX_SIDBSTORE_FLAGS_PRUNING_ENABLED.value != 0
+
+    @enable_store_pruning.setter
+    def enable_store_pruning(self, value):
+        """sets store purning value to true or false
+        Args:
+              value (bool) -- value to enable or disable store pruning
+        """
+        if not value:
+            new_value = self._store_flags & ~StoreFlags.IDX_SIDBSTORE_FLAGS_PRUNING_ENABLED.value
+        else:
+            new_value = self._store_flags | StoreFlags.IDX_SIDBSTORE_FLAGS_PRUNING_ENABLED.value
+
+        request_json = {
+            "EVGui_ParallelDedupConfigReq": {
+                "processinginstructioninfo": "",
+                "SIDBStore": {
+                    "SIDBStoreId": self.store_id,
+                    "SIDBStoreName": self.store_name,
+                    "extendedFlags": self._extended_flags,
+                    "flags": new_value,
+                    "minObjSizeKB": 50,
+                    "oldestEligibleObjArchiveTime": -1
+                },
+                "appTypeGroupId": 0,
+                "commCellId": 2,
+                "copyId": self.copy_id,
+                "operation": 3
+            }
+        }
+        output = self._commcell_object.qoperation_execute(request_json)
+        if output['error']['errorString'] != '':
+            raise SDKException('Storage', '102', output['error']['errorString'])
+
+        self.refresh()
+
     @enable_garbage_collection.setter
     def enable_garbage_collection(self, value):
         """sets enable garbage collection with true or false
@@ -664,6 +716,16 @@ class Store(object):
             self._commcell_object.qoperation_execute(request_json)
         self.refresh()
 
+    def seal_deduplication_database(self):
+        """ Seals the deduplication database """
+
+        request_json = {
+                        "App_SealSIDBStoreReq":{
+                                "SidbStoreId": self.store_id
+                            }
+                        }
+        self._commcell_object._qoperation_execute(request_json)
+
     def recover_deduplication_database(self, full_reconstruction=False, scalable_resources=True):
         """
         refresh store properties and start reconstruction job if at least one substore is marked for recovery
@@ -754,7 +816,7 @@ class Store(object):
         response_string = self._commcell_object._update_response_(response.text)
         raise SDKException('Response', '101', response_string)
 
-    def run_space_reclaimation(self, level=3, clean_orphan_data=False):
+    def run_space_reclaimation(self, level=3, clean_orphan_data=False, use_scalable_resource=False):
         """
         runs DDB Space reclaimation job with provided level
 
@@ -765,6 +827,8 @@ class Store(object):
             clean_orphan_data (bool) - run space reclaimation with OCL or not (True/False)
                         Default: False
 
+            use_scalable_resource (bool)    - Use Scalable Resource Allocation while running DDB Space Reclamation Job
+
         Returns:
              object - instance of Job class for DDB Verification job
 
@@ -781,6 +845,9 @@ class Store(object):
         if not (isinstance(level, int)) and level not in range(1, 4):
             raise SDKException('Storage', '101')
 
+        if not isinstance(use_scalable_resource, bool):
+            raise SDKException('Storage', '101')
+
         level_map = {
             1: 80,
             2: 60,
@@ -819,7 +886,7 @@ class Store(object):
                                         "mediaAgent": {
                                             "mediaAgentName": ""
                                         },
-                                        "useScallableResourceManagement": "false"
+                                        "useScallableResourceManagement": f"{use_scalable_resource}"
                                     }
                                 }
                             },
@@ -854,7 +921,8 @@ class Store(object):
         response_string = self._commcell_object._update_response_(response.text)
         raise SDKException('Response', '101', response_string)
 
-    def run_ddb_verification(self, incremental_verification=True, quick_verification=True):
+    def run_ddb_verification(self, incremental_verification=True, quick_verification=True,
+                             use_scalable_resource=False):
         """
         runs deduplication data verification(dv2) job with verification type and dv2 option
 
@@ -865,6 +933,8 @@ class Store(object):
             quick_verification (bool)       - DV2 job option, Quick or Complete (True/False)
                                             Default: True (quick verification)
 
+            use_scalable_resource (bool)    - Use Scalable Resource Allocation while running DDB Verification Job
+
         Returns:
              object - instance of Job class for DDB Verification job
 
@@ -885,6 +955,9 @@ class Store(object):
         if not quick_verification:
             verification_option = 'DDB_AND_DATA_VERIFICATION'
 
+        if not isinstance(use_scalable_resource, bool):
+            raise SDKException('Storage', '101')
+
         request_json = {
             "TMMsg_CreateTaskReq": {
                 "taskInfo": {
@@ -916,7 +989,7 @@ class Store(object):
                                         "mediaAgent": {
                                             "mediaAgentName": ""
                                         },
-                                        "useScallableResourceManagement": "false"
+                                        "useScallableResourceManagement": f"{use_scalable_resource}"
                                     }
                                 }
                             },
