@@ -220,9 +220,9 @@ class FailoverGroups(object):
             Args:
                 failover_group_options (json) -- failover group options for creating group
                 {
-                    "failoverGroupName": "FailoverAutomation-vApp",
-                    "failoverGroupVMs": "DRautoVM1, DRautoVM2",
-                    "VirtualizationClient": "vsa-vc6.testlab.commvault.com",
+                    "failoverGroupName": "",
+                    "failoverGroupVMs": "",
+                    "VirtualizationClient": "",
                     "approvalRequired": false,
                     "initiatedFromMonitor": false
                 }
@@ -398,9 +398,9 @@ class FailoverGroups(object):
             Args:
                 failover_group_options (json) -- failover group options for creating group
                 {
-                    "failoverGroupName": "FailoverAutomation-vApp",
-                    "failoverGroupVMs": "DRautoVM1, DRautoVM2",
-                    "VirtualizationClient": "vsa-vc6.testlab.commvault.com",
+                    "failoverGroupName": "",
+                    "failoverGroupVMs": "",
+                    "VirtualizationClient": "",
                     "approvalRequired": false,
                     "initiatedFromMonitor": false
                 }
@@ -497,17 +497,17 @@ class FailoverGroups(object):
         Returns: dict {
                     {
                     "client": {
-                        "subclientId": 22,
-                        "clientName": "testboot",
-                        "instanceId": 4,
-                        "clientId": 62,
-                        "GUID": "5026707a-0a15-d7c6-69a9-9f781514a932"
+                        "subclientId": 0,
+                        "clientName": "",
+                        "instanceId": 0,
+                        "clientId": 0,
+                        "GUID": ""
                     },
                     "lastbackuptime": {
                         "time": 1510332496
                     },
                     "backupSet": {
-                        "backupsetId": 6,
+                        "backupsetId": 0,
                         "backupsetName": "defaultBackupSet",
                         "applicationId": 0
                     },
@@ -515,10 +515,10 @@ class FailoverGroups(object):
                     "supportedOperation": 1,
                     "vendor": "VMW",
                     "copyPrecedence": 0,
-                    "scheduleName": "autoSCHDL",
+                    "scheduleName": "",
                     "destClient": {
-                        "clientName": "testboot_SDR",
-                        "GUID": "50267a1b-3939-2f52-4cba-3b941ac0840f"
+                        "clientName": "",
+                        "GUID": ""
                     },
                     "lastSyncTime": {
                         "time": 1510332235
@@ -527,8 +527,8 @@ class FailoverGroups(object):
                     "syncStatus": 1,
                     "failoverStatus": 0,
                     "destinationClient": {
-                        "clientName": "vsa-vc6",
-                        "clientId": 3
+                        "clientName": "",
+                        "clientId": 0
                     },
                     "destVendor": "VMW"
                 },
@@ -563,9 +563,9 @@ class FailoverGroups(object):
         Args: input dict of failover group options
                 failover_group_options (json) -- failover group options for creating group
                 {
-                    "failoverGroupName": "FailoverAutomation-vApp",
-                    "failoverGroupVMs": "DRautoVM1, DRautoVM2",
-                    "VirtualizationClient": "vsa-vc6.testlab.commvault.com",
+                    "failoverGroupName": "",
+                    "failoverGroupVMs": "",
+                    "VirtualizationClient": "",
                     "approvalRequired": false,
                     "initiatedFromMonitor": false
                 }
@@ -622,9 +622,9 @@ class FailoverGroups(object):
         Args: input dict of failover group options
                 failover_group_options (json) -- failover group options for creating group
                 {
-                    "failoverGroupName": "FailoverAutomation-vApp",
-                    "failoverGroupVMs": "DRautoVM1, DRautoVM2",
-                    "VirtualizationClient": "vsa-vc6.testlab.commvault.com",
+                    "failoverGroupName": "",
+                    "failoverGroupVMs": "",
+                    "VirtualizationClient": "",
                     "approvalRequired": false,
                     "initiatedFromMonitor": false
                 }
@@ -666,9 +666,9 @@ class FailoverGroups(object):
         Args: input dict of failover group options
                 failover_group_options (json) -- failover group options for creating group
                 {
-                    "failoverGroupName": "FailoverAutomation-vApp",
-                    "failoverGroupVMs": "DRautoVM1, DRautoVM2",
-                    "VirtualizationClient": "vsa-vc6.testlab.commvault.com",
+                    "failoverGroupName": "",
+                    "failoverGroupVMs": "",
+                    "VirtualizationClient": "",
                     "approvalRequired": false,
                     "initiatedFromMonitor": false
                 }
@@ -724,9 +724,9 @@ class FailoverGroup(object):
                 input dict of failover group options
                 failover_group_options (json) -- failover group options for creating group
                 {
-                    "failoverGroupName": "FailoverAutomation-vApp",
-                    "failoverGroupVMs": "DRautoVM1, DRautoVM2",
-                    "VirtualizationClient": "vsa-vc6.testlab.commvault.com",
+                    "failoverGroupName": "",
+                    "failoverGroupVMs": "",
+                    "VirtualizationClient": "",
                     "approvalRequired": false,
                     "initiatedFromMonitor": false
                 }
