@@ -77,6 +77,9 @@ MYSQLInstance instance Attributes:
 
     **proxy_options**                   -- Returns the MySQL Server proxy options
 
+    **mysql_enterprise_backup_binary_path** --  Returns the MySQL Enterprise backup binary path
+    details
+
 
 """
 
@@ -276,6 +279,36 @@ class MYSQLInstance(Instance):
             "clientName": proxy_settings.get('proxyInstance', {}).get('clientName', None)}
         return proxy_opt
 
+    @property
+    def mysql_enterprise_backup_binary_path(self):
+        """ Returns the MySQL Enterprise backup binary path detail
+
+            Return Type: dict
+
+        """
+        meb_settings = self._properties.get('mySqlInstance', {}).get('mebSettings', {})
+        return meb_settings
+
+    @mysql_enterprise_backup_binary_path.setter
+    def mysql_enterprise_backup_binary_path(self, value):
+        """ Setter for MySQL Enterprise backup binary path
+
+            Args:
+
+                value (str)  -- Contains the MySQL Enterprise backup binary path to be updated
+                in MySQL Instance property
+
+        """
+        if not isinstance(value, str):
+            raise SDKException('Instance', '101')
+        properties = self._properties
+        meb_bin_path_update = {
+            "enableMEB": False if value == '' else True,
+            "mebBinPath": value
+        }
+        properties['mySqlInstance']['mebSettings'] = meb_bin_path_update
+        self.update_properties(properties)
+
     def _get_instance_properties(self):
         """Gets the properties of this instance.
 
@@ -348,7 +381,8 @@ class MYSQLInstance(Instance):
             clone_env=False,
             clone_options=None,
             redirect_enabled=False,
-            redirect_path=None):
+            redirect_path=None,
+            browse_jobid=None):
         """Restores the mysql data/log files specified in the input paths list to the same location.
 
             Args:
@@ -435,6 +469,10 @@ class MYSQLInstance(Instance):
 
                     default: None
 
+                browse_jobid           (int)   --  Browse jobid to browse and restore from
+
+                    default: None
+
             Returns:
                 object - instance of the Job class for this restore job
 
@@ -478,7 +516,8 @@ class MYSQLInstance(Instance):
             clone_env=clone_env,
             clone_options=clone_options,
             redirect_enabled=redirect_enabled,
-            redirect_path=redirect_path)
+            redirect_path=redirect_path,
+            browse_jobid=browse_jobid)
 
         return self._process_restore_response(request_json)
 
@@ -493,6 +532,13 @@ class MYSQLInstance(Instance):
             "backupsetName": "defaultDummyBackupSet"
         }
 
+        if value.get("browse_jobid"):
+            self._browse_restore_json['browseJobId'] = value.get("browse_jobid")
+
+        if value.get("from_time") and value.get("to_time"):
+            self._browse_restore_json["timeRange"] = {"fromTime" : value.get("from_time"),
+                                                      "toTime" : value.get("to_time")}
+
     def _restore_common_options_json(self, value):
         """setter for the Common options in restore JSON"""
 
@@ -560,7 +606,7 @@ class MYSQLInstance(Instance):
             "dataStagingLocation": "",
             "logRestoreType": 0,
             "tableLevelRestore": value.get("table_level_restore", False),
-            "pointofTime": False,
+            "pointofTime": True if value.get("to_time") else False,
             "instanceRestore": True,
             "isCloneRestore": value.get("clone_env", False),
             "fromTime": value.get("from_time", {}),
@@ -579,3 +625,16 @@ class MYSQLInstance(Instance):
         if value.get("redirect_path"):
             self.mysql_restore_json["redirectEnabled"] = True
             self.mysql_restore_json["redirectItems"] = [value.get("redirect_path")]
+
+        if value.get("from_time"):
+            self.mysql_restore_json["fromTime"] = {"time" : value.get("to_time")}
+
+        if value.get("to_time"):
+            self.mysql_restore_json["refTime"] = {"time" : value.get("to_time")}
+
+        if value.get("to_time"):
+            self.mysql_restore_json["pointInTime"] = {"time" : value.get("to_time")}
+
+        if value.get("dest_instance_name"):
+            self.mysql_restore_json["destinationServer"] = {"name": value.get(
+                "dest_instance_name")}
