@@ -95,6 +95,8 @@ UserGroup:
 
     email()                         --  returns the email of this user group
 
+    company_name()                  --  returns the company name of this user group
+
     associations()                  --  Returns security associations present on the usergroup
 
     is_tfa_enabled()                --  Returns status of tfa
@@ -357,7 +359,7 @@ class UserGroups(object):
                 if 'response' in response.json():
                     response_json = response.json()['response'][0]
                     error_code = response_json['errorCode']
-                    error_message = response_json['errorString']
+                    error_message = response_json.get('errorString', '')
                     if not error_code == 0:
                         raise SDKException('Response', '101', error_message)
             else:
@@ -505,6 +507,7 @@ class UserGroup(object):
         self._users = []
         self._usergroups = []
         self._usergroup_status = None
+        self._company_name = None
         self.refresh()
 
     def __repr__(self):
@@ -551,6 +554,9 @@ class UserGroup(object):
                 if 'email' in self._properties:
                     self._email = self._properties['email']
 
+                if 'userGroupEntity' in self._properties:
+                    if 'entityInfo' in self._properties['userGroupEntity']: self._company_name = self._properties['userGroupEntity']['entityInfo'].get('companyName')
+
                 security_properties = self._properties.get('securityAssociations', {}).get(
                     'associations', {})
                 self._security_associations = SecurityAssociation.fetch_security_association(
@@ -603,6 +609,15 @@ class UserGroup(object):
         """Treats the usergroup email as a read-only attribute."""
         return self._email
 
+    @property
+    def company_name(self):
+        """
+        Returns:
+            str  -  company name to which user group belongs to.
+            str  -  empty string, if usergroup belongs to Commcell
+        """
+        return self._company_name
+
     def refresh(self):
         """Refresh the properties of the UserGroup."""
         self._get_usergroup_properties()
