@@ -35,6 +35,10 @@ FileSystemSubclient:
 
     _advanced_backup_options()          --  sets the advanced backup options
 
+    enable_content_indexing             --  Enables Content indexing and add the policy associations
+
+    disable_content_indexing            --  Disables Content indexing and disassociate the CI policy
+
     find_all_versions()                 --  returns the dict containing list of all the backed up
                                             versions of specified file
 
@@ -85,6 +89,12 @@ FileSystemSubclient Instance Attributes:
 
     **generate_signature_on_ibmi**        --  enable or disable signature generation on ibmi
 
+    **backup_using_multiple_drives**      --  enable or disable VTL multiple drives for ibmi subclient.
+
+    **pending_record_changes**            --  Updates the pending record changes value on ibmi subclient.
+
+    **other_pending_changes**             --  Updates the other pending changes value on ibmi subclient.
+
     **object_level_backup**               --  enable or disable object level backup for ibmi subclient
 
     **global_filter_status**              --  returns the status whther to include global filters
@@ -192,7 +202,7 @@ class FileSystemSubclient(Subclient):
 
         """
         super(FileSystemSubclient, self)._get_subclient_properties()
-
+        self._impersonateUser={}
         if 'impersonateUser' in self._subclient_properties:
             self._impersonateUser = self._subclient_properties['impersonateUser']
 
@@ -225,7 +235,8 @@ class FileSystemSubclient(Subclient):
 
                     "content": self._content,
                     "commonProperties": self._commonProperties,
-                    "contentOperationType": 1
+                    "fsContentOperationType": "OVERWRITE",
+                    "fsExcludeFilterOperationType": "OVERWRITE" if not hasattr(self, '_fsExcludeFilterOperationType') else self._fsExcludeFilterOperationType
                 }
         }
 
@@ -305,6 +316,8 @@ class FileSystemSubclient(Subclient):
             update_content.append(exception_dict)
 
         self._set_subclient_properties("_content", update_content)
+        self._fsExcludeFilterOperationType = "OVERWRITE"  # RESET THE OPERATION TYPE TO ITS DEFAULT
+
 
     def _common_backup_options(self, options):
         """
@@ -387,6 +400,28 @@ class FileSystemSubclient(Subclient):
             else:
                 final_dict['dataOpt'] = multi_stream_opts
 
+        if 'start_new_media' in options and options['start_new_media']:
+
+            media_opts = {
+                'startNewMedia': options.get('start_new_media', False)
+            }
+
+            if 'mediaOpt' in final_dict and isinstance(final_dict['mediaOpt'], dict):
+                final_dict['mediaOpt'].update(media_opts)
+            else:
+                final_dict['mediaOpt'] = media_opts
+        
+        if options.get('media_agent_name'):
+            media_agent_name = options['media_agent_name']
+            if not isinstance(media_agent_name, str):
+                message = f"media_agent_name: Expected str, received {type(media_agent_name)}"
+                raise SDKException('Subclient', '101', message)
+            final_dict['dataPathOpt'] = {
+                "mediaAgent": {
+                    "mediaAgentName": media_agent_name
+                }
+            }
+
         return final_dict
 
     @property
@@ -455,6 +490,7 @@ class FileSystemSubclient(Subclient):
     @filter_content.setter
     def filter_content(self, value):
         """Sets the filter content of the subclient as the value provided as input.
+            An empty list will clear all filters.
 
             example: ['*book*', 'file**']
 
@@ -464,15 +500,17 @@ class FileSystemSubclient(Subclient):
 
                     if the type of value input is not list
 
-                    if value list is empty
         """
-        if isinstance(value, list) and value != []:
+        if isinstance(value, list):
+            if value == []:
+                value = self.filter_content
+                self._fsExcludeFilterOperationType = "DELETE"
             self._set_content(filter_content=value)
         else:
             raise SDKException(
                 'Subclient',
                 '102',
-                'Subclient filter content should be a list value and not empty')
+                'Subclient filter content should be a list value')
 
     @property
     def exception_content(self):
@@ -747,7 +785,13 @@ class FileSystemSubclient(Subclient):
 
         """
 
-        return self._fsSubClientProp['afterDeletionKeepItemsForNDays']
+        # For Indexing V2 clients
+        if 'afterDeletionKeepItemsForNDays' in self._fsSubClientProp:
+            return self._fsSubClientProp['afterDeletionKeepItemsForNDays']
+
+        # For Indexing V1 clients
+        else:
+            return self._fsSubClientProp.get('daysToKeepItems', 0)
 
     @backup_retention_days.setter
     def backup_retention_days(self, value):
@@ -770,12 +814,19 @@ class FileSystemSubclient(Subclient):
         """
 
         if isinstance(value, int):
-            if value != -1:
-                new_value = {
-                    'afterDeletionKeepItemsForNDays': value,
-                    'backupRetentionMode': 1}
+            if 'afterDeletionKeepItemsForNDays' in self._fsSubClientProp:
+                if value != -1:
+                    new_value = {
+                        'afterDeletionKeepItemsForNDays': value,
+                        'backupRetentionMode': 1
+                    }
+                else:
+                    new_value = {'afterDeletionKeepItemsForNDays': value}
             else:
-                new_value = {'afterDeletionKeepItemsForNDays': value}
+                new_value = {
+                    'daysToKeepItems': value
+                }
+
             self._set_subclient_properties("_fs_subclient_prop", new_value)
 
         else:
@@ -1129,6 +1180,14 @@ class FileSystemSubclient(Subclient):
                         (dict)  --  file version mode
         """
         version = {}
+
+        # For Indexing V1 client, this property is not supported. Taking default versions by number
+        if 'olderFileVersionsMode' not in self._fsSubClientProp:
+            return {
+                'Mode': 2,
+                'DaysOrNumber': self._fsSubClientProp.get('keepAtLeastPreviousVersions', 0)
+            }
+
         version['Mode'] = self._fsSubClientProp['olderFileVersionsMode']
         modes = {
             1: self._fsSubClientProp['keepOlderVersionsForNDays'],
@@ -1165,18 +1224,27 @@ class FileSystemSubclient(Subclient):
                     if value is invalid
 
         """
-        if isinstance(value, dict):
-            if value['Mode'] == 1 or value['Mode'] == 2:
-                new_value = {'olderFileVersionsMode': value['Mode']}
-            else:
-                raise SDKException(
-                    'Subclient', '102', "File version mode can only be 1 or 2")
-            modes = {
-                1: 'keepOlderVersionsForNDays',
-                2: 'keepVersions'
-            }
 
-            new_value[modes[value['Mode']]] = value['DaysOrNumber']
+        if isinstance(value, dict):
+            # For Indexing V2 client
+            if 'olderFileVersionsMode' in self._fsSubClientProp:
+                if value['Mode'] == 1 or value['Mode'] == 2:
+                    new_value = {'olderFileVersionsMode': value['Mode']}
+                else:
+                    raise SDKException(
+                        'Subclient', '102', "File version mode can only be 1 or 2")
+                modes = {
+                    1: 'keepOlderVersionsForNDays',
+                    2: 'keepVersions'
+                }
+
+                new_value[modes[value['Mode']]] = value['DaysOrNumber']
+
+            # For Indexing V1 client
+            else:
+                new_value = {
+                    'keepAtLeastPreviousVersions': value['DaysOrNumber']
+                }
 
             self._set_subclient_properties("_fs_subclient_prop", new_value)
         else:
@@ -1208,6 +1276,81 @@ class FileSystemSubclient(Subclient):
             generate_signature_value
         )
 
+    @property
+    def backup_using_multiple_drives(self):
+        """Gets the value of VTL multiple drives on ibmi option for IBMi subclient.
+
+            Returns:
+                False   -   if multiple drives is not enabled.
+
+                True    -   if multiple drives is enabled.
+        """
+        return bool(self._fsSubClientProp.get('backupUsingMultipleDrives',False))
+
+    @backup_using_multiple_drives.setter
+    def backup_using_multiple_drives(self, set_vtl_multiple_drives):
+        """Updates the VTL multiple drives property value on ibmi subclient.
+
+            Args:
+                set_vtl_multiple_drives (bool)  --  Enable or disable VTL multiple drives on IBMi
+        """
+        update_properties = self.properties
+        if isinstance(set_vtl_multiple_drives, bool):
+            update_properties['fsSubClientProp']['backupUsingMultipleDrives'] = set_vtl_multiple_drives
+        else:
+            raise SDKException('Subclient', '101')
+        self.update_properties(update_properties)
+    
+    @property
+    def pending_record_changes(self):
+        """Gets the value of pending record changes option for  IBMi subclient.
+
+            Returns:
+                False   -   if multiple drives is not enabled.
+
+                True    -   if multiple drives is enabled.
+        """
+        return bool(self._fsSubClientProp.get('pendingRecordChange'))
+
+    @pending_record_changes.setter
+    def pending_record_changes(self, value):
+        """Updates the pending record changes value on ibmi subclient.
+
+            Args:
+                value   (str)  --  To set pending records changes value for backup data.
+        """
+        update_properties = self.properties
+        if isinstance(value, str):
+            update_properties['fsSubClientProp']['pendingRecordChange'] = value
+        else:
+            raise SDKException('Subclient', '101')
+        self.update_properties(update_properties)
+
+    @property
+    def other_pending_changes(self):
+        """Gets the value of other pending changes for IBMi subclient.
+
+            Returns:
+                False   -   if multiple drives is not enabled.
+
+                True    -   if multiple drives is enabled.
+        """
+        return bool(self._fsSubClientProp.get('otherPendingChange'))
+
+    @other_pending_changes.setter
+    def other_pending_changes(self, value):
+        """Updates the other pending changes value on ibmi subclient.
+
+            Args:
+                value   (str)  --  To set other pending changes value for backup data.
+        """
+        update_properties = self.properties
+        if isinstance(value, str):
+            update_properties['fsSubClientProp']['otherPendingChange'] = value
+        else:
+            raise SDKException('Subclient', '101')
+        self.update_properties(update_properties)
+
     @property
     def object_level_backup(self):
         """Gets the value of object level backup option for IBMi subclient.
@@ -1480,7 +1623,7 @@ class FileSystemSubclient(Subclient):
                         only applicable in case of on demand subclient
                     default: None
 
-                advacnced_options   (dict)  --  advanced backup options to be included while
+                advanced_options    (dict)  --  advanced backup options to be included while
                                                     making the request
                         default: None
 
@@ -1490,6 +1633,8 @@ class FileSystemSubclient(Subclient):
                             adhoc_backup_contents   :   sets the contents for adhoc backup
                             inline_backup_copy      :   to run backup copy immediately(inline)
                             skip_catalog            :   skip catalog for intellisnap operation
+                            start_new_media         :   enables the option to start new media for the job
+                            media_agent_name        :   to run backup via this media agent
 
                 common_backup_options      (dict)  --  advanced job options to be included while
                                                         making request
@@ -1870,6 +2015,19 @@ class FileSystemSubclient(Subclient):
                 advanced_options=advanced_options
             )
 
+    def enable_content_indexing(self, policy_id):
+        """Enables Content indexing and add the policy associations"""
+        update_properties = self.properties
+        update_properties['fsSubClientProp']['enableContentIndexing'] = True
+        update_properties['fsSubClientProp']['contentIndexingPolicy'] = int(policy_id)
+        self.update_properties(update_properties)
+
+    def disable_content_indexing(self):
+        """Disables Content indexing and disassociate the CI policy"""
+        update_properties = self.properties
+        update_properties['fsSubClientProp']['enableContentIndexing'] = False
+        self.update_properties(update_properties)
+
     @property
     def catalog_acl(self):
         """Gets the catalog acl option
@@ -2428,4 +2586,4 @@ class FileSystemSubclient(Subclient):
             update_properties["impersonateUser"]["userName"] = value["username"]
             update_properties["impersonateUser"]["password"] = b64encode(value["password"].encode()).decode()
 
-        self.update_properties(update_properties)
\ No newline at end of file
+        self.update_properties(update_properties)
